Daemon rucio-c3po — Rucio 1.2 documentation

# Daemon rucio-c3po

    usage: rucio-c3po [-h] [--run-once] [--threads THREADS] [--only-workload]
                      [--dry_run] [--sampling] [--algorithms ALGORITHMS]
                      [--datatypes DATATYPES] [--dest_rse_expr DEST_RSE_EXPR]
                      [--max_bytes_hour MAX_BYTES_HOUR]
                      [--max_files_hour MAX_FILES_HOUR]
                      [--max_bytes_hour_rse MAX_BYTES_HOUR_RSE]
                      [--max_files_hour_rse MAX_FILES_HOUR_RSE]
                      [--min_popularity MIN_POPULARITY]
                      [--min_recent_requests MIN_RECENT_REQUESTS]
                      [--max_replicas MAX_REPLICAS]

## Named Arguments

`--run-once` | One iteration only Default: False
`--threads` | Concurrency control: number of threads Default: 1
`--only-workload`
| Only run the workload collector Default: False
`--dry_run` | Do not create any rules Default: False
`--sampling` | In the end flip a to decide to create a rule or not Default: False
`--algorithms` | The placement algorithm or, if in dry_run, a comma separated list of algorithms Default: “t2_free_space_only_pop_with_network”
`--datatypes` | Comma separated list of datatype that should trigger the placement Default: “NTUP,DAOD”
`--dest_rse_expr`
| RSE expression defining the allowed destination RSEs Default: “type=DATADISK”
`--max_bytes_hour`
| Max number of bytes that c3po is allow to replicate per hour Default: 100000000000000
`--max_files_hour`
| Max number of files that c3po is allow to replicate per hour Default: 100000
`--max_bytes_hour_rse`
| Max number of bytes that c3po is allow to replicate per hour per rse Default: 50000000000000
`--max_files_hour_rse`
| Max number of files that c3po is allow to replicate per hour prse_rse Default: 10000
`--min_popularity`
| Min number of popularity accesses for a DID in the last 7 days to trigger Default: 8
`--min_recent_requests`
| Min number of times a DID has to be requested in the last hour to trigger Default: 5
`--max_replicas` | Max number of replicas above which not to trigger anymore Default: 5